@@ -87,7 +87,8 @@ describe_colorscheme (FILE *fp, ggobid *gg)
     OPEN_C(fp);  /* one foreground color */
     describe_color (fp, scheme->rgb[i]);
     CLOSE_C(fp);  /* one foreground color */
-    ADD_COMMA(fp);
+    if (i < scheme->n-1)
+      ADD_COMMA(fp);
   }
   CLOSE_LIST(fp); /* foregroundColors */
 
@@ -108,6 +109,7 @@ describe_sticky_labels (FILE *fp, GGobiData *d, cpaneld *cpanel)
 
   if (d->sticky_ids && g_slist_length (d->sticky_ids) > 0) {
     GSList *l;
+    ADD_COMMA(fp);
     OPEN_NAMED_LIST(fp, "stickylabels");
     for (l = d->sticky_ids; l; l = l->next) {
       OPEN_LIST(fp);  /* one sticky label */
@@ -128,7 +130,8 @@ describe_sticky_labels (FILE *fp, GGobiData *d, cpaneld *cpanel)
         }
       }
       CLOSE_LIST(fp);  /* one sticky label */
-      ADD_COMMA(fp);  /* an extra comma seems to do no harm */
+      if (l->next)
+        ADD_COMMA(fp); 
     }
     CLOSE_LIST(fp);  /* stickylabels */
   }
@@ -277,86 +280,100 @@ describe_scatterplot_plot (FILE *fp, ggobid *gg, displayd *display,
 
   /* raw row number -- the edges use these  */
   OPEN_NAMED_C(fp, "index");
-  for (m=0, counter=0; m<d->nrows_in_plot; m++, counter++) {
+  for (m=0, counter=1; m<d->nrows_in_plot; m++, counter++) {
     i = d->rows_in_plot.els[m];
     if (counter % MAX_PER_ROW == 0) ADD_CR(fp);
-    fprintf (fp, "%d,", i);
+    fprintf (fp, "%d", i);
+    if (m < d->nrows_in_plot-1)
+      ADD_COMMA(fp);
   }
   CLOSE_C(fp); ADD_COMMA(fp); ADD_CR(fp);
 
   /* x coordinates */
   OPEN_NAMED_C(fp, "x");
-  for (m=0, counter=0; m<d->nrows_in_plot; m++, counter++) {
+  for (m=0, counter=1; m<d->nrows_in_plot; m++, counter++) {
     i = d->rows_in_plot.els[m];
     if (projection == P1PLOT) {
-      fprintf (fp, "%g,", d->tform.vals[i][sp->p1dvar]);
+      fprintf (fp, "%g", d->tform.vals[i][sp->p1dvar]);
     } else if (projection == XYPLOT) {
-      fprintf (fp, "%g,", d->tform.vals[i][sp->xyvars.x]);
+      fprintf (fp, "%g", d->tform.vals[i][sp->xyvars.x]);
       /*  Is this how to add jittering to tform?
-      fprintf (fp, "%g,", d->tform.vals[i][sp->xyvars.x] +
+      fprintf (fp, "%g", d->tform.vals[i][sp->xyvars.x] +
 	       d->jitdata.vals[i][sp->xyvars.x] / precis);
       */
     } else {  /* planar already includes jitdata! */
-      fprintf (fp, "%g,", sp->planar[i].x);
+      fprintf (fp, "%g", sp->planar[i].x);
     }
+    if (m < d->nrows_in_plot-1)
+      ADD_COMMA(fp);
     if (counter % MAX_PER_ROW == 0) ADD_CR(fp);
   }
   CLOSE_C(fp); ADD_COMMA(fp); ADD_CR(fp);
 
   /* y coordinates */
   OPEN_NAMED_C(fp, "y");
-  for (m=0, counter=0; m<d->nrows_in_plot; m++, counter++) {
+  for (m=0, counter=1; m<d->nrows_in_plot; m++, counter++) {
     i = d->rows_in_plot.els[m];
     if (projection == P1PLOT) {
       /* I <think> spread_data is in tform coordinates, but it's hard
          to tell.  And maybe it doesn't matter because the spread axis
          isn't going to be labelled.
       */
-      fprintf (fp, "%g,", sp->p1d.spread_data.els[m]);
+      fprintf (fp, "%g", sp->p1d.spread_data.els[m]);
     } else if (projection == XYPLOT) {
-      fprintf (fp, "%g,", d->tform.vals[i][sp->xyvars.y]);
+      fprintf (fp, "%g", d->tform.vals[i][sp->xyvars.y]);
     } else {
-      fprintf (fp, "%g,", sp->planar[i].y);
+      fprintf (fp, "%g", sp->planar[i].y);
     }
+    if (m < d->nrows_in_plot-1)
+      ADD_COMMA(fp);
     if (counter % MAX_PER_ROW == 0) ADD_CR(fp);
   }
   CLOSE_C(fp); ADD_COMMA(fp); ADD_CR(fp);
 
   /* color */
   OPEN_NAMED_C(fp, "color");
-  for (m=0, counter=0; m<d->nrows_in_plot; m++, counter++) {
+  for (m=0, counter=1; m<d->nrows_in_plot; m++, counter++) {
     i = d->rows_in_plot.els[m];
-    fprintf (fp, "%d,", d->color_now.els[i]);
+    fprintf (fp, "%d", d->color_now.els[i]);
+    if (m < d->nrows_in_plot-1)
+      ADD_COMMA(fp);
     if (counter % MAX_PER_ROW == 0) ADD_CR(fp);
   }
   CLOSE_C(fp); ADD_COMMA(fp); ADD_CR(fp);
 
   /* glyphtype */
   OPEN_NAMED_C(fp, "glyphtype");
-  for (m=0, counter=0; m<d->nrows_in_plot; m++, counter++) {
+  for (m=0, counter=1; m<d->nrows_in_plot; m++, counter++) {
     i = d->rows_in_plot.els[m];
-    fprintf (fp, "%d,", d->glyph_now.els[i].type);
+    fprintf (fp, "%d", d->glyph_now.els[i].type);
+    if (m < d->nrows_in_plot-1)
+      ADD_COMMA(fp);
     if (counter % MAX_PER_ROW == 0) ADD_CR(fp);
   }
   CLOSE_C(fp); ADD_COMMA(fp); ADD_CR(fp);
 
   /* glyphsize */
   OPEN_NAMED_C(fp, "glyphsize");
-  for (m=0, counter=0; m<d->nrows_in_plot; m++, counter++) {
+  for (m=0, counter=1; m<d->nrows_in_plot; m++, counter++) {
     i = d->rows_in_plot.els[m];
-    fprintf (fp, "%d,", d->glyph_now.els[i].size);
+    fprintf (fp, "%d", d->glyph_now.els[i].size);
+    if (m < d->nrows_in_plot-1)
+      ADD_COMMA(fp);
     if (counter % MAX_PER_ROW == 0) ADD_CR(fp);
   }
   CLOSE_C(fp); ADD_COMMA(fp); ADD_CR(fp);
 
   /* hiddenness */
   OPEN_NAMED_C(fp, "hidden");
-  for (m=0, counter=0; m<d->nrows_in_plot; m++, counter++) {
+  for (m=0, counter=1; m<d->nrows_in_plot; m++, counter++) {
     i = d->rows_in_plot.els[m];
-    fprintf (fp, "%d,", d->hidden_now.els[i]);
+    fprintf (fp, "%d", d->hidden_now.els[i]);
+    if (m < d->nrows_in_plot-1)
+      ADD_COMMA(fp);
     if (counter % MAX_PER_ROW == 0) ADD_CR(fp);
   }
-  CLOSE_C(fp); ADD_COMMA(fp); ADD_CR(fp);
+  CLOSE_C(fp); /*ADD_COMMA(fp);*/ ADD_CR(fp);
 
   /* missingness */
   /*
@@ -398,7 +415,7 @@ describe_scatterplot_plot (FILE *fp, ggobid *gg, displayd *display,
     vt = vartable_element_get (sp->xyvars.x, d);
     fprintf (fp, "xlabel='%s',", vt->collab_tform);
     vt = vartable_element_get (sp->xyvars.y, d);
-    fprintf (fp, "ylabel='%s',", vt->collab_tform);
+    fprintf (fp, "ylabel='%s'", vt->collab_tform);
     CLOSE_LIST(fp);  /* xyplot params */
   } else if (projection == TOUR1D) {
     /* F, variable labels, variable lims */
@@ -407,7 +424,9 @@ describe_scatterplot_plot (FILE *fp, ggobid *gg, displayd *display,
     OPEN_NAMED_C(fp, "F");
     for (k=0; k<display->t1d.nsubset; k++) {
       j = display->t1d.subset_vars.els[k];
-      fprintf (fp, "%.3f,", display->t1d.F.vals[0][j]);
+      fprintf (fp, "%.3f", display->t1d.F.vals[0][j]);
+      if (k < display->t1d.nsubset-1)
+        ADD_COMMA(fp);
     }
     CLOSE_C(fp);
     ADD_COMMA(fp);
@@ -416,7 +435,9 @@ describe_scatterplot_plot (FILE *fp, ggobid *gg, displayd *display,
     for (k=0; k<display->t1d.nsubset; k++) {
       j = display->t1d.subset_vars.els[k];
       vt = vartable_element_get (j, d);
-      fprintf (fp, "'%s',", vt->collab_tform);
+      fprintf (fp, "'%s'", vt->collab_tform);
+      if (k < display->t1d.nsubset-1)
+        ADD_COMMA(fp);
     }
     CLOSE_C(fp);
     ADD_COMMA(fp);
@@ -428,7 +449,8 @@ describe_scatterplot_plot (FILE *fp, ggobid *gg, displayd *display,
       OPEN_C(fp);
       fprintf (fp, "%.3f, %.3f", vt->lim.min, vt->lim.max);
       CLOSE_C(fp);
-      ADD_COMMA(fp);
+      if (k < display->t1d.nsubset-1)
+        ADD_COMMA(fp);
     }
     CLOSE_LIST(fp);  /* tour1d ranges */
     CLOSE_LIST(fp);  /* tour1d params */
@@ -439,11 +461,15 @@ describe_scatterplot_plot (FILE *fp, ggobid *gg, displayd *display,
     OPEN_NAMED_C(fp, "F");
     for (k=0; k<display->t2d3.nsubset; k++) {
       j = display->t2d3.subset_vars.els[k];
-      fprintf (fp, "%.3f,", display->t2d3.F.vals[0][j]);
+      fprintf (fp, "%.3f", display->t2d3.F.vals[0][j]);
+      if (k < display->t2d3.nsubset-1)
+        ADD_COMMA(fp);
     }
     for (k=0; k<display->t2d3.nsubset; k++) {
       j = display->t2d3.subset_vars.els[k];
-      fprintf (fp, "%.3f,", display->t2d3.F.vals[1][j]);
+      fprintf (fp, "%.3f", display->t2d3.F.vals[1][j]);
+      if (k < display->t2d3.nsubset-1)
+        ADD_COMMA(fp);
     }
     CLOSE_C(fp);
     ADD_COMMA(fp);
@@ -452,7 +478,9 @@ describe_scatterplot_plot (FILE *fp, ggobid *gg, displayd *display,
     for (k=0; k<display->t2d3.nsubset; k++) {
       j = display->t2d3.subset_vars.els[k];
       vt = vartable_element_get (j, d);
-      fprintf (fp, "'%s',", vt->collab_tform);
+      fprintf (fp, "'%s'", vt->collab_tform);
+      if (k < display->t2d3.nsubset-1)
+        ADD_COMMA(fp);
     }
     CLOSE_C(fp);
     ADD_COMMA(fp);
@@ -464,7 +492,8 @@ describe_scatterplot_plot (FILE *fp, ggobid *gg, displayd *display,
       OPEN_C(fp);
       fprintf (fp, "%.3f, %.3f", vt->lim.min, vt->lim.max);
       CLOSE_C(fp);
-      ADD_COMMA(fp);
+      if (k < display->t2d3.nsubset-1)
+        ADD_COMMA(fp);
     }
     CLOSE_LIST(fp);  /* tour2d3 ranges */
     CLOSE_LIST(fp);  /* tour2d3 params */
@@ -475,11 +504,16 @@ describe_scatterplot_plot (FILE *fp, ggobid *gg, displayd *display,
     OPEN_NAMED_C(fp, "F");
     for (k=0; k<display->t2d.nsubset; k++) {
       j = display->t2d.subset_vars.els[k];
-      fprintf (fp, "%.3f,", display->t2d.F.vals[0][j]);
+      fprintf (fp, "%.3f", display->t2d.F.vals[0][j]);
+      if (k < display->t2d.nsubset-1)
+        ADD_COMMA(fp);
     }
+    ADD_COMMA(fp);
     for (k=0; k<display->t2d.nsubset; k++) {
       j = display->t2d.subset_vars.els[k];
-      fprintf (fp, "%.3f,", display->t2d.F.vals[1][j]);
+      fprintf (fp, "%.3f", display->t2d.F.vals[1][j]);
+      if (k < display->t2d.nsubset-1)
+        ADD_COMMA(fp);
     }
     CLOSE_C(fp);  /* F */
     ADD_COMMA(fp);
@@ -488,7 +522,9 @@ describe_scatterplot_plot (FILE *fp, ggobid *gg, displayd *display,
     for (k=0; k<display->t2d.nsubset; k++) {
       j = display->t2d.subset_vars.els[k];
       vt = vartable_element_get (j, d);
-      fprintf (fp, "'%s',", vt->collab_tform);
+      fprintf (fp, "'%s'", vt->collab_tform);
+      if (k < display->t2d.nsubset-1)
+        ADD_COMMA(fp);
     }
     CLOSE_C(fp); /* labels */
     ADD_COMMA(fp);
@@ -500,7 +536,8 @@ describe_scatterplot_plot (FILE *fp, ggobid *gg, displayd *display,
       OPEN_C(fp);
       fprintf (fp, "%.3f, %.3f", vt->lim.min, vt->lim.max);
       CLOSE_C(fp);
-      ADD_COMMA(fp);
+      if (k < display->t2d.nsubset-1)
+        ADD_COMMA(fp);
     }
     CLOSE_LIST(fp);   /* tour2d ranges */
     CLOSE_LIST(fp);  /* tour2d params */
@@ -511,7 +548,9 @@ describe_scatterplot_plot (FILE *fp, ggobid *gg, displayd *display,
     OPEN_NAMED_C(fp, "xF");
     for (k=0; k<display->tcorr1.nsubset; k++) {
       j = display->tcorr1.subset_vars.els[k];
-      fprintf (fp, "%.3f,", display->tcorr1.F.vals[0][j]);
+      fprintf (fp, "%.3f", display->tcorr1.F.vals[0][j]);
+      if (k < display->tcorr1.nsubset-1)
+        ADD_COMMA(fp);
     }
     CLOSE_C(fp);
     ADD_COMMA(fp);
@@ -520,7 +559,9 @@ describe_scatterplot_plot (FILE *fp, ggobid *gg, displayd *display,
     for (k=0; k<display->tcorr1.nsubset; k++) {
       j = display->tcorr1.subset_vars.els[k];
       vt = vartable_element_get (j, d);
-      fprintf (fp, "'%s',", vt->collab_tform);
+      fprintf (fp, "'%s'", vt->collab_tform);
+      if (k < display->tcorr1.nsubset-1)
+        ADD_COMMA(fp);
     }
     CLOSE_C(fp);
     ADD_COMMA(fp);
@@ -532,7 +573,8 @@ describe_scatterplot_plot (FILE *fp, ggobid *gg, displayd *display,
       OPEN_C(fp);
       fprintf (fp, "%.3f, %.3f", vt->lim.min, vt->lim.max);
       CLOSE_C(fp);
-      ADD_COMMA(fp);
+      if (k < display->tcorr1.nsubset-1)
+        ADD_COMMA(fp);
     }
     CLOSE_LIST(fp);  /* tour2x1d, x ranges */
 
@@ -542,7 +584,9 @@ describe_scatterplot_plot (FILE *fp, ggobid *gg, displayd *display,
     OPEN_NAMED_C(fp, "yF");
     for (k=0; k<display->tcorr2.nsubset; k++) {
       j = display->tcorr2.subset_vars.els[k];
-      fprintf (fp, "%.3f,", display->tcorr2.F.vals[0][j]);
+      fprintf (fp, "%.3f", display->tcorr2.F.vals[0][j]);
+      if (k < display->tcorr2.nsubset-1)
+        ADD_COMMA(fp);
     }
     CLOSE_C(fp);
     ADD_COMMA(fp);
@@ -551,7 +595,9 @@ describe_scatterplot_plot (FILE *fp, ggobid *gg, displayd *display,
     for (k=0; k<display->tcorr2.nsubset; k++) {
       j = display->tcorr2.subset_vars.els[k];
       vt = vartable_element_get (j, d);
-      fprintf (fp, "'%s',", vt->collab_tform);
+      fprintf (fp, "'%s'", vt->collab_tform);
+      if (k < display->tcorr2.nsubset-1)
+        ADD_COMMA(fp);
     }
     CLOSE_C(fp);
     ADD_COMMA(fp);
@@ -563,13 +609,14 @@ describe_scatterplot_plot (FILE *fp, ggobid *gg, displayd *display,
       OPEN_C(fp);
       fprintf (fp, "%.3f, %.3f", vt->lim.min, vt->lim.max);
       CLOSE_C(fp);
-      ADD_COMMA(fp);
+      if (k < display->tcorr2.nsubset-1)
+        ADD_COMMA(fp);
     }
     CLOSE_LIST(fp);  /* tour2x1d, y ranges */
 
     CLOSE_LIST(fp);  /* tour2x1d params */
   }
-  ADD_COMMA(fp);
+  /*  ADD_COMMA(fp); */ 
 
   /* sticky labels */
   describe_sticky_labels (fp, d, cpanel);
@@ -589,6 +636,7 @@ describe_scatterplot_plot (FILE *fp, ggobid *gg, displayd *display,
          display->options.edges_arrowheads_show_p ||
 	 display->options.edges_directed_show_p))
     {
+      ADD_COMMA(fp);
       OPEN_NAMED_LIST(fp, "edges");
 
       for (i=0; i<e->edge.n; i++) {
@@ -617,13 +665,14 @@ describe_scatterplot_plot (FILE *fp, ggobid *gg, displayd *display,
           splot_hidden_edge (i, d, e, sp, display, gg));
 
         CLOSE_LIST(fp);  /* one edge */
-        ADD_COMMA(fp);
+        if (i < e->edge.n-1)
+          ADD_COMMA(fp);
       }
       /* sticky labels */
       describe_sticky_labels (fp, e, cpanel);
     }
     CLOSE_LIST(fp);  /* edges */
-    ADD_COMMA(fp); ADD_CR(fp);
+    /*ADD_COMMA(fp); */ ADD_CR(fp);
   }
 
   CLOSE_LIST(fp); /* plot */
@@ -655,6 +704,9 @@ describe_scatmat_display (FILE *fp, ggobid *gg, displayd *display,
   gint ncols, *cols;
   ProjectionMode projection;
   GGobiData *d = display->d;
+  gint i, j, nplotted_vars, *plotted_vars;
+  GtkTableChild *child;
+  GtkWidget *da;
 
   cols = (gint *) g_malloc(d->ncols * sizeof(gint));
   ncols = GGOBI_EXTENDED_DISPLAY_GET_CLASS(display)->plotted_vars_get(display, cols, d, gg);
@@ -664,20 +716,40 @@ describe_scatmat_display (FILE *fp, ggobid *gg, displayd *display,
   OPEN_NAMED_LIST(fp, "plots");
 
   /* This output relies on the idea that we'll use 
-     par(mfcol=, mfrow=) to layout the plots in composite displays,
+     par(mfcol=, mfrow=) to lay out the plots in composite displays,
      rather than using splom or any other utility. */
 
-  /* We seem to be working through the plots row-wise, but I don't
-  think that's something we can count on.  I hope we can make use of
-  the axis labels to figure out which plot belongs where.  Otherwise,
-  I'll have to add a position indicator to each plot. */
+  plotted_vars = (gint *) g_malloc (d->ncols * sizeof (gint));
+  nplotted_vars =
+    GGOBI_EXTENDED_DISPLAY_GET_CLASS (display)->plotted_vars_get (display,
+      plotted_vars, d, gg);
 
+  for (i=0; i<nplotted_vars; i++) {
+    for (j=0; j<nplotted_vars; j++) {
+
+      for (l = (GTK_TABLE (display->table))->children; l; l = l->next) {
+        child = (GtkTableChild *) l->data;
+        if (child->top_attach==i && child->left_attach==j) {
+          da = child->widget;
+          sp = (splotd *) g_object_get_data (G_OBJECT (da), "splotd");
+          projection = (sp->p1dvar != -1) ? P1PLOT : XYPLOT;
+          describe_scatterplot_plot (fp, gg, display, sp, desc, projection);
+          ADD_COMMA(fp);
+          break;
+        }
+      }
+    }
+  }
+
+  /*
   for (l = display->splots; l; l = l->next) {
     sp = (splotd *) l->data;
     projection = (sp->p1dvar != -1) ? P1PLOT : XYPLOT;
     describe_scatterplot_plot (fp, gg, display, sp, desc, projection);
-    ADD_COMMA(fp);
+    if (l->next)
+      ADD_COMMA(fp);
   }
+  */
 
   CLOSE_LIST(fp);  /* plots */
   g_free(cols);
@@ -729,12 +801,138 @@ describe_time_series_display (FILE *fp, ggobid *gg, displayd *display,
   for (l = display->splots; l; l = l->next) {
     sp = (splotd *) l->data;
     describe_scatterplot_plot (fp, gg, display, sp, desc, XYPLOT);
-    ADD_COMMA(fp);
+    if (l->next)
+      ADD_COMMA(fp);
   }
 
   CLOSE_LIST(fp);  /* plots */
 }
 
+void
+describe_barchart_plot (FILE *fp, ggobid *gg, displayd *display,
+   splotd *sp, dspdescd *desc)
+{
+  GGobiData *d = display->d;
+  barchartSPlotd *bsp = GGOBI_BARCHART_SPLOT (sp);
+  vartabled *vtx = vartable_element_get (sp->p1dvar, d);
+  gint i, m, level, counter;
+
+  OPEN_LIST(fp);  /* plot; unlabelled */
+  if (vtx->vartype == categorical) {
+    if (bsp->bar->is_spine)
+      fprintf (fp, "type='spineplot'");
+    else
+      fprintf (fp, "type='barplot'");
+  } else {
+    fprintf (fp, "type='histogram'");
+  }
+  ADD_COMMA(fp);
+
+
+  OPEN_NAMED_LIST(fp, "points");
+  /* x coordinates */
+  OPEN_NAMED_C(fp, "x");
+  for (m=0, counter=1; m<d->nrows_in_plot; m++, counter++) {
+    i = d->rows_in_plot.els[m];
+    fprintf (fp, "%g", d->tform.vals[i][sp->p1dvar]);
+    if (m < d->nrows_in_plot-1)
+      ADD_COMMA(fp);
+    if (counter % MAX_PER_ROW == 0) ADD_CR(fp);
+  }
+  CLOSE_C(fp); ADD_COMMA(fp); ADD_CR(fp);
+
+  /* color */
+  OPEN_NAMED_C(fp, "color");
+  for (m=0, counter=1; m<d->nrows_in_plot; m++, counter++) {
+    i = d->rows_in_plot.els[m];
+    fprintf (fp, "%d", d->color_now.els[i]);
+    if (m < d->nrows_in_plot-1)
+      ADD_COMMA(fp);
+    if (counter % MAX_PER_ROW == 0) ADD_CR(fp);
+  }
+  CLOSE_C(fp); ADD_COMMA(fp); ADD_CR(fp);
+
+  /* hiddenness */
+  OPEN_NAMED_C(fp, "hidden");
+  for (m=0, counter=1; m<d->nrows_in_plot; m++, counter++) {
+    i = d->rows_in_plot.els[m];
+    fprintf (fp, "%d", d->hidden_now.els[i]);
+    if (m < d->nrows_in_plot-1)
+      ADD_COMMA(fp);
+    if (counter % MAX_PER_ROW == 0) ADD_CR(fp);
+  }
+  CLOSE_C(fp); ADD_COMMA(fp); ADD_CR(fp);
+
+  CLOSE_LIST(fp);  /* points */
+  ADD_COMMA(fp);
+  ADD_CR(fp);
+
+  /* parameters */
+  OPEN_NAMED_LIST(fp, "params");
+  /* Variable name */
+  fprintf (fp, "label='%s',", vtx->collab_tform);
+
+
+  if (vtx->vartype == categorical) {
+    gchar *catname;
+
+    /* level names */
+    OPEN_NAMED_C(fp, "levelnames");
+    for (i = 0; i < bsp->bar->nbins; i++) {
+      level = checkLevelValue (vtx, (gdouble) bsp->bar->bins[i].value);
+      catname = g_strdup_printf ("%s",
+                                 (level ==
+                                  -1) ? "missing" : vtx->level_names[level]);
+      fprintf (fp, "'%s'", catname);
+      if (i < bsp->bar->nbins-1) 
+        ADD_COMMA(fp);
+      if (i % MAX_PER_ROW == 0) ADD_CR(fp);
+    }
+    CLOSE_C(fp); ADD_COMMA(fp); ADD_CR(fp);
+
+    /* level values */
+    OPEN_NAMED_C(fp, "levelvalues");
+    for (i = 0; i < bsp->bar->nbins; i++) {
+      level = checkLevelValue (vtx, (gdouble) bsp->bar->bins[i].value);
+      fprintf (fp, "%d", level);
+      if (i < bsp->bar->nbins-1) 
+        ADD_COMMA(fp);
+      if (i % MAX_PER_ROW == 0) ADD_CR(fp);
+    }
+    CLOSE_C(fp); ADD_COMMA(fp); ADD_CR(fp);
+  } else {
+    /* breaks */
+    OPEN_NAMED_C(fp, "breaks");
+    for (i = 0; i < bsp->bar->nbins; i++) {
+      if (i < bsp->bar->nbins-1) 
+        ADD_COMMA(fp);
+      fprintf (fp, "%.3f", bsp->bar->breaks[i]);
+    }
+    CLOSE_C(fp); ADD_COMMA(fp); ADD_CR(fp);
+  }
+
+  CLOSE_LIST(fp);  /* params */
+  ADD_COMMA(fp);
+  ADD_CR(fp);
+
+  CLOSE_LIST(fp); /* plot */
+}
+
+void describe_barchart_display (FILE *fp, ggobid *gg, displayd *display, 
+		      dspdescd *desc)
+{
+  splotd *sp = (splotd *) display->splots->data;
+
+  fprintf (fp, "nplots=1");
+  ADD_COMMA(fp); ADD_CR(fp);
+  OPEN_NAMED_LIST(fp, "plots");
+
+  describe_barchart_plot (fp, gg, display, sp, desc);
+
+  CLOSE_LIST(fp);  /* plots */
+}
+
+
 void
 desc_setup (dspdescd *desc)
 {
@@ -781,7 +979,8 @@ desc_write (PluginInstance *inst)
   /* describe the colorscheme here, once for all (potential) displays */
   describe_colorscheme (fp, gg);
 
-  fprintf (fp, "title='%s',", desc->title);
+  if (desc->title)
+    fprintf (fp, "title='%s',", desc->title);
 
   /* A display could report its own name, but I don't know if it can */
   if (GGOBI_IS_SCATTERPLOT_DISPLAY(display)) {
@@ -805,12 +1004,12 @@ desc_write (PluginInstance *inst)
     fprintf (fp, "type='timeseries',");
     fprintf (fp, "ncols = %d,", g_list_length (display->splots));
     describe_time_series_display (fp, gg, display, desc);
-  /*
   } else if (GGOBI_IS_BARCHART_DISPLAY(display)) {
-    fprintf (fp, "type='barchart',");
+    fprintf (fp, "type='barchart',");  /* barchart or histogram */
+    describe_barchart_display (fp, gg, display, desc);
+  /*
     -- is_histogram and is_spine are attributes of the plot, not the
        display : sp->bar->is_histogram, etc.
-    describe_barchart_display (gg, display, desc, display_node);
     -- this will call describe_barchart_plot
     -- other useful attributes: nbins, breaks
   */
@@ -826,7 +1025,7 @@ desc_write (PluginInstance *inst)
     display->options.edges_directed_show_p);
   fprintf (fp, "showUndirectedEdges=%d,",
     display->options.edges_undirected_show_p);
-  fprintf (fp, "showArrowheads=%d,",
+  fprintf (fp, "showArrowheads=%d",
     display->options.edges_arrowheads_show_p);
 
   CLOSE_LIST(fp);
