@@ -708,13 +708,14 @@ endXMLElement (void *user_data, const xmlChar * name)
     {
       GGobiData *d = getCurrentXMLData (data);
 
-      setEdgePartners (data);
-      releaseCurrentDataInfo (data);
       if (data->current_record < d->nrows) {
         g_error ("There are fewer records than declared for '%s': %d < %d.",
                  d->name, data->current_record, d->nrows);
       }
 
+      setEdgePartners (data);
+      releaseCurrentDataInfo (data);
+
       data->dlist = g_slist_append (data->dlist, d);
 
     }
@@ -851,7 +852,7 @@ Characters (void *user_data, const xmlChar * ch, gint len)
     return;
 
   if (data->terminateStrings_p) {
-    tmp = g_strndup(c, dlen);
+    tmp = g_strndup((gchar *)c, dlen);
     c = (const xmlChar *) tmp;
   }
 
@@ -1329,7 +1330,7 @@ setRecordValue (const char *tmp, GGobiData * d, XMLParserData * data)
       if (vt && vt->vartype == categorical) {
         /* To be correct, we need to match the level_values and find the
            corresponding entry. */
-        tmp1 = (gchar *) GGobi_getLevelName (vt, value);
+        tmp1 = g_strchomp((gchar *) GGobi_getLevelName (vt, value));
         if (tmp1)
           tmp1 = g_strdup (tmp1);
       }
